@@ -132,7 +132,7 @@ drawColorKey <- function(
   key.pos       = c(.925,.975,.05,.95),
   pos           = 2,
   nlevels       = length(tick.marks),
-  color.palette = viridis::viridis(nlevels),
+  color.palette = viridisLite::viridis(nlevels),
   tick.width    = c(.01,.0075),
   add.box       = TRUE,
   na.col        = NULL,
